Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(823)

Unified Diff: remoting/test/test_chromoting_client.h

Issue 1237093004: Support for connecting to localhost on the chromoting test driver. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Cleaned up ConnectionSetupInfo, comments, and merge changes. Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/test/test_chromoting_client.h
diff --git a/remoting/test/test_chromoting_client.h b/remoting/test/test_chromoting_client.h
index 03c942f7bb822ee5639bc27e0c0f3ff8ee52eaa4..cb1ef7911ffeacbcd4ae7750bb387fe30aa5cdb9 100644
--- a/remoting/test/test_chromoting_client.h
+++ b/remoting/test/test_chromoting_client.h
@@ -14,6 +14,7 @@
#include "remoting/client/client_user_interface.h"
#include "remoting/protocol/clipboard_filter.h"
#include "remoting/protocol/cursor_shape_stub.h"
+#include "remoting/test/connection_setup_info.h"
Sergey Ulanov 2015/07/16 23:42:10 ConnectionSetupInfo is passed by reference so it c
tonychun 2015/07/17 16:25:49 Done.
#include "remoting/test/remote_connection_observer.h"
#include "remoting/test/remote_host_info.h"
@@ -27,7 +28,7 @@ namespace protocol {
class ClipboardStub;
class HostStub;
class InputStub;
-}
+} // namespace protocol
namespace test {
@@ -45,10 +46,8 @@ class TestChromotingClient : public ClientUserInterface,
explicit TestChromotingClient(scoped_ptr<VideoRenderer> video_renderer);
~TestChromotingClient() override;
- // Starts a chromoting connection with the specified remote host.
- void StartConnection(const std::string& user_name,
- const std::string& access_token,
- const RemoteHostInfo& remote_host_info);
+ // Starts a Chromoting connection using the specified connection setup info.
+ void StartConnection(const ConnectionSetupInfo& connection_setup_info);
// Ends the current remote connection and updates the connection state.
void EndConnection();

Powered by Google App Engine
This is Rietveld 408576698